@@ -2,7 +2,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# SPDX-FileCopyrightText: 2024 Univention GmbH
+# SPDX-FileCopyrightText: 2024-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 from univention.config_registry.interfaces import Interfaces, _Iface
@@ -49,6 +49,4 @@ class PhaseRestartAllInterfaces(Phase):
             return False
         if iface.ipv4_address():
             return True
-        if any(iface.ipv6_address(name) for name in iface.ipv6_names):
-            return True
-        return False
+        return bool(any(iface.ipv6_address(name) for name in iface.ipv6_names))
