@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2012-2024 Univention GmbH
+# Copyright 2012-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -223,8 +223,7 @@ class SetupScript:
 
         # remove script path from name
         self.script_name = os.path.abspath(sys.argv[0])
-        if self.script_name.startswith(PATH_SETUP_SCRIPTS):
-            self.script_name = self.script_name[len(PATH_SETUP_SCRIPTS):]
+        self.script_name = self.script_name.removeprefix(PATH_SETUP_SCRIPTS)
 
         self.profile = self.parse_profile()
 
